@@ -90,11 +90,22 @@ class VersionObjectFetcher(object):
             )
             .correlate(table)
         )
-        return query
+        try:
+            return query.scalar_subquery()
+        except AttributeError:  # SQLAlchemy < 1.4
+            return query.as_scalar()
 
     def _next_prev_query(self, obj, next_or_prev='next'):
         session = sa.orm.object_session(obj)
 
+        subquery = self._transaction_id_subquery(
+            obj, next_or_prev=next_or_prev
+        )
+        try:
+            subquery = subquery.scalar_subquery()
+        except AttributeError:  # SQLAlchemy < 1.4
+            subquery = subquery.as_scalar()
+
         return (
             session.query(obj.__class__)
             .filter(
@@ -102,11 +113,7 @@ class VersionObjectFetcher(object):
                     getattr(
                         obj.__class__,
                         tx_column_name(obj)
-                    )
-                    ==
-                    self._transaction_id_subquery(
-                        obj, next_or_prev=next_or_prev
-                    ),
+                    ) == subquery,
                     *parent_criteria(obj)
                 )
             )
